[−][src]Enum rustfmt_nightly::ErrorKind
The various errors that can occur during formatting. Note that not all of these can currently be propagated to clients.
Variants
LineOverflow(usize, usize)Line has exceeded character limit (found, maximum).
TrailingWhitespaceLine ends in whitespace.
BadIssue(Issue)TODO or FIXME item without an issue number.
LicenseCheckLicense check has failed.
DeprecatedAttrUsed deprecated skip attribute.
BadAttrUsed a rustfmt:: attribute other than skip or skip::macros.
IoError(Error)An io error during reading or writing.
ParseErrorParse error occurred when parsing the input.
VersionMismatchThe user mandated a version and the current version of Rustfmt does not satisfy that requirement.
LostCommentIf we had formatted the given node, then we would have lost a comment.
InvalidGlobPattern(Error)Invalid glob pattern in ignore configuration option.