Struct rustfmt_nightly::FormatReport [−][src]
pub struct FormatReport { /* fields omitted */ }Reports on any issues that occurred during a run of Rustfmt.
Can be reported to the user via its Display implementation of print_fancy.
Methods
impl FormatReport[src]
impl FormatReportpub fn has_warnings(&self) -> bool[src]
pub fn has_warnings(&self) -> boolWhether any warnings or errors are present in the report.
pub fn fancy_print(
&self,
t: Box<Terminal<Output = Stderr>>
) -> Result<(), Error>[src]
pub fn fancy_print(
&self,
t: Box<Terminal<Output = Stderr>>
) -> Result<(), Error>Print the report to a terminal using colours and potentially other fancy output.